from clinicedc_constants import NOT_APPLICABLE

from .constants import MORE_THAN_HALF, NEARLY_EVERYDAY, NOT_AT_ALL, SEVERAL_DAYS

PHQ_CHOICES = (
    (NOT_AT_ALL, "Not at all"),
    (SEVERAL_DAYS, "Several days"),
    (MORE_THAN_HALF, "More than half the days"),
    (NEARLY_EVERYDAY, "Nearly everyday"),
    (NOT_APPLICABLE, "Not applicable"),
)
